from conductor.client.http.models import Task, TaskResult
from conductor.client.http.models.task_result_status import TaskResultStatus
from conductor.client.worker.worker_interface import WorkerInterface


class TaskWorker(WorkerInterface):
    def __init__(self, name, execute_function):
        super().__init__(name)
        self.execute_function = execute_function

    def execute(self, task: Task) -> TaskResult:
        task_result = self.get_task_result_from_task(task)
        execution_return_value = self.execute_function(task)
        if not isinstance(execution_return_value, dict):
            execution_return_value = {execution_return_value}
        task_result = execution_return_value
        task_result.status = TaskResultStatus.COMPLETED
        return task_result



from conductor.client.automator.task_handler import TaskHandler
from conductor.client.example.worker.cpp.simple_cpp_worker import SimpleCppWorker
from conductor.client.example.worker.python.simple_python_worker import SimplePythonWorker


def main():
    workers = [
        SimpleCppWorker('cpp_task_example'),
        SimplePythonWorker('python_task_example')
    ]
    with TaskHandler(workers) as task_handler:
        task_handler.start_processes()
        task_handler.join_processes()


if __name__ == '__main__':
    main()



from conductor.client.configuration.configuration import Configuration
from pathlib import Path
import logging
import os

logger = logging.getLogger(
    Configuration.get_logging_formatted_name(
        __name__
    )
)


def get_default_temporary_folder() -> str:
    try:
        metrics_dir = str(Path.home()) + '/tmp/'
        if not os.path.isdir(metrics_dir):
            os.mkdir(metrics_dir)
        return metrics_dir
    except Exception as e:
        logger.warning('failed to create metrics temporary folder')


class MetricsSettings:
    def __init__(
            self,
            directory: str = None,
            file_name: str = 'metrics.log',
            update_interval: float = 0.1):
        if directory == None:
            directory = get_default_temporary_folder()
        self.directory = directory
        self.file_name = file_name
        self.update_interval = update_interval
